# lasfile
 Library for reading CWLS Log ASCII Standard v. 1.2, 2.0, and 3.0 .las files.

## Installation
```bash
pip install lasfile
```

## Usage
```python
import lasfile

las = lasfile.LASFile(file_path='path/to/file.las')
```

## License
[MIT](https://choosealicense.com/licenses/mit/)
```